# scikit-credit
scikit-credit 是用于信贷风控评分卡建模的自动化工具。如下是 scikit-credit 的简介：
* 自动分箱
* 特征选择
* 模型训练 
* 评分生成

# 玩家
信贷风控模型分析师

# 安装

```
pip install skcredit
```

# 示例

[example.ipynb](https://github.com/JYLFamily/scikit-credit/blob/master/examples/example.ipynb)